@@ -12,9 +12,12 @@
 #' \tabular{ll}{
 #' Package: \tab regressoR\cr
 #' Type: \tab Package\cr
-#' Version: \tab 2.0.1\cr
-#' Date: \tab 2021-08-30\cr
+#' Version: \tab 3.0.0\cr
+#' Date: \tab 2023-02-15\cr
 #' License: \tab GPL (>=2)\cr
 #' }
 #' @keywords package
 #' @docType package
+
+NULL
+utils::globalVariables(c( "name", "value", "color"))
\ No newline at end of file
